pub struct Query;Trait Implementations
Sourceimpl<__S> BaseSubTypes<__S> for Querywhere
__S: ScalarValue,
impl<__S> BaseSubTypes<__S> for Querywhere
__S: ScalarValue,
Sourceconst NAMES: Types
const NAMES: Types
Sub-[
Types] of the GraphQL object.Sourceimpl<__S> BaseType<__S> for Querywhere
__S: ScalarValue,
impl<__S> BaseType<__S> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> Field<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
impl<__S> FieldMeta<__S, #[graphql_object(
context = Context,
)]> for Querywhere
__S: ScalarValue,
Sourceconst TYPE: Type
const TYPE: Type
[
Types] of GraphQL field’s return type.Sourceconst SUB_TYPES: Types
const SUB_TYPES: Types
Sub-types of GraphQL field’s return type.
Sourceconst WRAPPED_VALUE: WrappedValue
const WRAPPED_VALUE: WrappedValue
[
WrappedValue] of GraphQL field’s return type.Sourceconst ARGUMENTS: &'static [(Name, Type, WrappedValue)]
const ARGUMENTS: &'static [(Name, Type, WrappedValue)]
GraphQL field’s [
Arguments].Sourcetype TypeInfo = ()
type TypeInfo = ()
GraphQLValue::TypeInfo of this GraphQL field.Sourceimpl<__S> GraphQLObject<__S> for Querywhere
__S: ScalarValue,
impl<__S> GraphQLObject<__S> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> GraphQLType<__S> for Querywhere
__S: ScalarValue,
impl<__S> GraphQLType<__S> for Querywhere
__S: ScalarValue,
Sourceimpl<__S> GraphQLValue<__S> for Querywhere
__S: ScalarValue,
impl<__S> GraphQLValue<__S> for Querywhere
__S: ScalarValue,
Sourcetype TypeInfo = ()
type TypeInfo = ()
Type that may carry additional schema information for this
GraphQLValue. Read moreSourcefn resolve_field(
&self,
info: &Self::TypeInfo,
field: &str,
args: &Arguments<'_, __S>,
executor: &Executor<'_, '_, Self::Context, __S>,
) -> ExecutionResult<__S>
fn resolve_field( &self, info: &Self::TypeInfo, field: &str, args: &Arguments<'_, __S>, executor: &Executor<'_, '_, Self::Context, __S>, ) -> ExecutionResult<__S>
Resolves the value of a single field on this
GraphQLValue. Read moreSourcefn concrete_type_name(&self, _: &Self::Context, _: &Self::TypeInfo) -> String
fn concrete_type_name(&self, _: &Self::Context, _: &Self::TypeInfo) -> String
Returns the concrete
GraphQLType name for this GraphQLValue being an interface,
an union or an object. Read moreSourcefn resolve_into_type(
&self,
info: &Self::TypeInfo,
type_name: &str,
selection_set: Option<&[Selection<'_, S>]>,
executor: &Executor<'_, '_, Self::Context, S>,
) -> Result<Value<S>, FieldError<S>>
fn resolve_into_type( &self, info: &Self::TypeInfo, type_name: &str, selection_set: Option<&[Selection<'_, S>]>, executor: &Executor<'_, '_, Self::Context, S>, ) -> Result<Value<S>, FieldError<S>>
Resolves this
GraphQLValue (being an interface or an union) into a concrete
downstream object type. Read moreSourceimpl<__S> GraphQLValueAsync<__S> for Query
impl<__S> GraphQLValueAsync<__S> for Query
Sourcefn resolve_field_async<'b>(
&'b self,
info: &'b Self::TypeInfo,
field: &'b str,
args: &'b Arguments<'_, __S>,
executor: &'b Executor<'_, '_, Self::Context, __S>,
) -> BoxFuture<'b, ExecutionResult<__S>>
fn resolve_field_async<'b>( &'b self, info: &'b Self::TypeInfo, field: &'b str, args: &'b Arguments<'_, __S>, executor: &'b Executor<'_, '_, Self::Context, __S>, ) -> BoxFuture<'b, ExecutionResult<__S>>
Resolves the value of a single field on this
GraphQLValueAsync. Read moreSourcefn resolve_into_type_async<'a>(
&'a self,
info: &'a Self::TypeInfo,
type_name: &str,
selection_set: Option<&'a [Selection<'a, S>]>,
executor: &'a Executor<'a, 'a, Self::Context, S>,
) -> Pin<Box<dyn Future<Output = Result<Value<S>, FieldError<S>>> + Send + 'a>>
fn resolve_into_type_async<'a>( &'a self, info: &'a Self::TypeInfo, type_name: &str, selection_set: Option<&'a [Selection<'a, S>]>, executor: &'a Executor<'a, 'a, Self::Context, S>, ) -> Pin<Box<dyn Future<Output = Result<Value<S>, FieldError<S>>> + Send + 'a>>
Resolves this
GraphQLValueAsync (being an interface or an union) into a
concrete downstream object type. Read moreSourceimpl<__S> Implements<__S> for Querywhere
__S: ScalarValue,
impl<__S> Implements<__S> for Querywhere
__S: ScalarValue,
Sourceconst NAMES: Types
const NAMES: Types
[
Types] of the GraphQL interfaces implemented by this type.Sourceimpl<__S> IsOutputType<__S> for Querywhere
__S: ScalarValue,
impl<__S> IsOutputType<__S> for Querywhere
__S: ScalarValue,